#if defined _vip_estus_included
	#endinput
#endif
#define _vip_estus_included

/**
 *	Игрок собирается использовать эстус.
 *
 *	@param price				Стоимость (0 = бесплатный).
 *	@param hp					Здоровье, которое будет добавлено (число > 0).
 *
 *	@return						Plugin_Continue/Plugin_Changed = разрешить. Plugin_Stop = запретить.
 */
forward Action OnUseEstus(int client, int &price, int &hp);

/**
 *	Игрок использовал эстус.
 *
 *	@param price				Стоимость (0 = бесплатный).
 *	@param hp					Здоровье, которое было добавлено. Может быть меньше, чем в OnUseEstus, если упёрлось в максимальное (ConVar "estus_max_hp").
 */
forward void OnUseEstusPost(int client, int price, int hp);

/**
 *	Оповещение о том, могут ли функции/нативы восстановить игроку здоровье.
 *
 *	@note						Если было оповещение @param canRecoverHealth false и игрок умер или начался новый раунд, то оповещения @param canRecoverHealth true не будет.
 *								В этом случае, если вы храните @param canRecoverHealth статус в глобальной переменной, то просто установите её в true в player_spawn.
 *
 *	@param client				Живой игрок. Возможно бот.
 *
 *	@param canRecoverHealth		true  = игроку разрешено восстанавливать здоровье. Он не получал урон в течение "estus_delay_after_damage" (ConVar) секунд.
 *								false = запрещено. Будет доступно через GetClientHealthRecoveryDelay секунд. Игрока ранил враг (или товарищ при mp_friendlyfire 1) в событии player_hurt.
 */
forward void OnStatusOfHealthRecoveryFunctionsChanged(int client, bool canRecoverHealth);

/**
 *	Получить максимальное hp игрока в текущем раунде.
 *	@note			Если ConVar "estus_max_hp" > 0, то вернёт "estus_max_hp".
 */
native int GetClientMaxHp(int client);

/**
 *	Получить время в секундах, через которое игроку будет разрешено использовать функции восстановления здоровья.
 *
 *	@note			Зависит от ConVar "estus_delay_after_damage":
 *
 *					// Если игрока ранил враг (или товарищ при mp_friendlyfire 1),
 *					// то через сколько секунд игрок может начать использовать функции восстановления здоровья?
 *					// 0.0 = сразу же.
 *					estus_delay_after_damage "5.0"
 *
 *	@return			0.0 = функции восстановления здоровья разрешены. Если > 0.0, то запрещены ещё в течение 'x' секунд.
 */
native float GetClientHealthRecoveryDelay(int client);

/**
 *	Получить значение ConVar "estus_delay_after_damage".
 *	@note			После OnLibraryAdded("VipEstusLib") должно пройти немного времени, иначе вернёт 0.0.
 */
native float GetHealthRecoveryDelay();

/**
 *	Получить время ( GetGameTime() ) последнего получения урона от врага (или товарища при mp_friendlyfire 1).
 *	@note			Урон от самого себя не учитывается.
 */
native float GetClientLastDamageTime(int client);

public SharedPlugin __pl_VipEstusVar = 
{
	name = "VipEstusLib",		/* Имя библиотеки */
	file = "ws_vip/estus.smx",
	required = 0				/* Не требуется, т.к. включается с задержкой (позже обычных .smx). */
};

public void __pl_VipEstusVar_SetNTVOptional()
{
	MarkNativeAsOptional("GetClientMaxHp");
	MarkNativeAsOptional("GetClientHealthRecoveryDelay");
	MarkNativeAsOptional("GetHealthRecoveryDelay" );
	MarkNativeAsOptional("GetClientLastDamageTime");
}

/* 

/////

// https://world-source.ru/vip_modules/estus.zip
#include <vip_estus>
static const char g_sVipEstusLib[] = "VipEstusLib";
bool g_bVipEstusLib = false;
public void OnAllPluginsLoaded	() { g_bVipEstusLib = LibraryExists(g_sVipEstusLib); }
public void OnLibraryAdded		(const char[] name) { if (!strcmp(name, g_sVipEstusLib)) { g_bVipEstusLib = true ; } }
public void OnLibraryRemoved	(const char[] name) { if (!strcmp(name, g_sVipEstusLib)) { g_bVipEstusLib = false; } }

/////

*/